
#-----------------------------------------------------------------------------
MACRO(ImageIO_THIRD_PARTY_OPTION upper lower)
  OPTION(ImageIO_USE_SYSTEM_${upper} "Use the system's ${lower} library." OFF)
  MARK_AS_ADVANCED(ImageIO_USE_SYSTEM_${upper})
  IF(ImageIO_USE_SYSTEM_${upper})
    IF(EXISTS ${CMAKE_ROOT}/Modules/Find${upper}.cmake)
      INCLUDE(${CMAKE_ROOT}/Modules/Find${upper}.cmake)
    ELSE(EXISTS ${CMAKE_ROOT}/Modules/Find${upper}.cmake)
      INCLUDE(${ImageIO_SOURCE_DIR}/Utilities/Find${upper}.cmake)
    ENDIF(EXISTS ${CMAKE_ROOT}/Modules/Find${upper}.cmake)
    MARK_AS_ADVANCED(${upper}_INCLUDE_DIR ${upper}_LIBRARY)
    IF(${upper}_FOUND)
      SET(ImageIO_${upper}_LIBRARIES ${${upper}_LIBRARIES})
      IF("${upper}" MATCHES "^PNG$")
        SET(PNG_INCLUDE_DIR ${PNG_PNG_INCLUDE_DIR})
        MARK_AS_ADVANCED(PNG_PNG_INCLUDE_DIR)
      ENDIF("${upper}" MATCHES "^PNG$")
    ELSE(${upper}_FOUND)
      MESSAGE(SEND_ERROR "ImageIO_USE_SYSTEM_${upper} is ON, but ${upper}_LIBRARY is NOTFOUND.")
    ENDIF(${upper}_FOUND)
  ELSE(ImageIO_USE_SYSTEM_${upper})
    SET(ImageIO_${upper}_LIBRARIES ImageIO${lower})
    MESSAGE("** ImageIO_${upper}_LIBRARIES=${ImageIO_${upper}_LIBRARIES}")
  ENDIF(ImageIO_USE_SYSTEM_${upper})
ENDMACRO(ImageIO_THIRD_PARTY_OPTION)

#-----------------------------------------------------------------------------
# The in-tree third-party libraries are not exported.  We only need
# the include directory inside the tree.  If using a third-party
# library from the system, though, make sure the system include
# directory is consistent inside and outside the tree.
MACRO(ImageIO_THIRD_PARTY_INCLUDE upper lower)
  IF(ImageIO_USE_SYSTEM_${upper})
    IF(${upper}_INCLUDE_DIR)
      SET(ImageIO_INCLUDE_DIRS_SYSTEM ${ImageIO_INCLUDE_DIRS_SYSTEM} ${${upper}_INCLUDE_DIR})
    ENDIF(${upper}_INCLUDE_DIR)
  ELSE(ImageIO_USE_SYSTEM_${upper})
    SET(ImageIO_INCLUDE_DIRS_BUILD_TREE_CXX ${ImageIO_INCLUDE_DIRS_BUILD_TREE_CXX}
      ${ImageIO_SOURCE_DIR}/Utilities/${lower}
      ${ImageIO_BINARY_DIR}/Utilities/${lower}
      )
  ENDIF(ImageIO_USE_SYSTEM_${upper})
ENDMACRO(ImageIO_THIRD_PARTY_INCLUDE)

MACRO(ImageIO_THIRD_PARTY_INCLUDE2 upper)
  IF(ImageIO_USE_SYSTEM_${upper})
    IF(${upper}_INCLUDE_DIR)
      SET(ImageIO_INCLUDE_DIRS_SYSTEM ${ImageIO_INCLUDE_DIRS_SYSTEM} ${${upper}_INCLUDE_DIR})
    ENDIF(${upper}_INCLUDE_DIR)
  ENDIF(ImageIO_USE_SYSTEM_${upper})
ENDMACRO(ImageIO_THIRD_PARTY_INCLUDE2)

#-----------------------------------------------------------------------------
MACRO(ImageIO_THIRD_PARTY_SUBDIR upper lower)
  IF(NOT ImageIO_USE_SYSTEM_${upper})
#    SUBDIRS(image/${lower})
    SUBDIRS(${CMAKE_CURRENT_SOURCE_DIR}/${lower})
  ENDIF(NOT ImageIO_USE_SYSTEM_${upper})
ENDMACRO(ImageIO_THIRD_PARTY_SUBDIR)
